//
// C++ Interface: %{MODULE}
//
// Description: 
//
//
// Author: %{AUTHOR} <%{EMAIL}>, (C) %{YEAR}
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGDCOPTALKTHREAD_H
#define KPGDCOPTALKTHREAD_H

#include <qthread.h>

class DCOPClient;

/**
  *
  * Thread that talk with Console part via DCOP
  *
  * @author Lumir Vanek
  * @deprecated L.V. 25.3.2009 Now, backup/restore wizards uses ExtTerminalInterface, rather than unreliable DCOP
  */
class KPGDcopTalkThread : public QThread
{
public:
    KPGDcopTalkThread();
    ~KPGDcopTalkThread();

    void setDcopClient(DCOPClient *);
    void setCommand(const QString &);
    
protected:
    virtual void run();
    
protected:  
    DCOPClient *m_pDcopClient;
    QString m_strCommand; // Command for Console
    bool m_bSessionClosed;
};

#endif



